@@ -1,4 +1,4 @@
-use super::{AnnotationStorage, Match, MatchGroup};
+use super::{AnnotationStorage, Match};
 use crate::annostorage::ValueSearch;
 use crate::errors::Result;
 use crate::malloc_size_of::MallocSizeOf;
@@ -8,6 +8,7 @@ use crate::{annostorage::symboltable::SymbolTable, errors::GraphAnnisCoreError};
 use core::ops::Bound::*;
 use itertools::Itertools;
 use rustc_hash::{FxHashMap, FxHashSet};
+use smallvec::SmallVec;
 use smartstring::alias::String;
 use std::borrow::Cow;
 use std::collections::{BTreeMap, HashMap};
@@ -407,11 +408,11 @@ where
         ns: Option<&str>,
         name: Option<&str>,
         it: Box<dyn Iterator<Item = T>>,
-    ) -> MatchGroup {
+    ) -> SmallVec<[Match; 8]> {
         if let Some(name) = name {
             if let Some(ns) = ns {
                 // return the only possible annotation for each node
-                let mut matches = MatchGroup::new();
+                let mut matches = SmallVec::<[Match; 8]>::new();
                 let key = Arc::from(AnnoKey {
                     ns: ns.into(),
                     name: name.into(),
@@ -441,7 +442,7 @@ where
                     })
                     .collect();
                 // return all annotations with the correct name for each node
-                let mut matches = MatchGroup::new();
+                let mut matches = SmallVec::<[Match; 8]>::new();
                 for item in it {
                     for (key_symbol, key) in matching_key_symbols.iter() {
                         if let Some(all_annos) = self.by_container.get(&item) {
@@ -458,7 +459,7 @@ where
             }
         } else {
             // return all annotations for each node
-            let mut matches = MatchGroup::new();
+            let mut matches = SmallVec::<[Match; 8]>::new();
             for item in it {
                 let all_keys = self.get_all_keys_for_item(&item, None, None);
                 for anno_key in all_keys {
